/*
 * (C) Copyright 2011 Samsung Electronics Co. Ltd
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 */

#ifndef __BQ24160_H__
#define __BQ24160_H__

#define GPD1CON		*(volatile unsigned long *)(0x114000C0)
#define GPD1DAT		*(volatile unsigned long *)(0x114000C4)
#define GPD1PUD		*(volatile unsigned long *)(0x114000C8)
#ifdef CONFIG_SMDKC220
#define GPA1CON		*(volatile unsigned long *)(0x11400020)
#define GPA1DAT		*(volatile unsigned long *)(0x11400024)
#define GPA1PUD		*(volatile unsigned long *)(0x11400028)
#endif

#ifdef CONFIG_INVERSE_PMIC_I2C
#define IIC0_ESCL_Hi	GPD1DAT |= (0x1<<0)
#define IIC0_ESCL_Lo	GPD1DAT &= ~(0x1<<0)
#define IIC0_ESDA_Hi	GPD1DAT |= (0x1<<1)
#define IIC0_ESDA_Lo	GPD1DAT &= ~(0x1<<1)
#else
#define IIC0_ESCL_Hi	GPD1DAT |= (0x1<<1)
#define IIC0_ESCL_Lo	GPD1DAT &= ~(0x1<<1)
#define IIC0_ESDA_Hi	GPD1DAT |= (0x1<<0)
#define IIC0_ESDA_Lo	GPD1DAT &= ~(0x1<<0)
#endif

#define IIC1_ESCL_Hi	GPD1DAT |= (0x1<<3)
#define IIC1_ESCL_Lo	GPD1DAT &= ~(0x1<<3)
#define IIC1_ESDA_Hi	GPD1DAT |= (0x1<<2)
#define IIC1_ESDA_Lo	GPD1DAT &= ~(0x1<<2)

#ifdef CONFIG_SMDKC220
#define IIC3_ESCL_Hi	GPA1DAT |= (0x1<<3)
#define IIC3_ESCL_Lo	GPA1DAT &= ~(0x1<<3)
#define IIC3_ESDA_Hi	GPA1DAT |= (0x1<<2)
#define IIC3_ESDA_Lo	GPA1DAT &= ~(0x1<<2)
#endif

#ifdef CONFIG_INVERSE_PMIC_I2C
#define IIC0_ESCL_INP	GPD1CON &= ~(0xf<<0)
#define IIC0_ESCL_OUTP	GPD1CON = (GPD1CON & ~(0xf<<0))|(0x1<<0)

#define IIC0_ESDA_INP	GPD1CON &= ~(0xf<<4)
#define IIC0_ESDA_OUTP	GPD1CON = (GPD1CON & ~(0xf<<4))|(0x1<<4)
#else
#define IIC0_ESCL_INP	GPD1CON &= ~(0xf<<4)
#define IIC0_ESCL_OUTP	GPD1CON = (GPD1CON & ~(0xf<<4))|(0x1<<4)

#define IIC0_ESDA_INP	GPD1CON &= ~(0xf<<0)
#define IIC0_ESDA_OUTP	GPD1CON = (GPD1CON & ~(0xf<<0))|(0x1<<0)
#endif

#define IIC1_ESCL_INP	GPD1CON &= ~(0xf<<12)
#define IIC1_ESCL_OUTP	GPD1CON = (GPD1CON & ~(0xf<<12))|(0x1<<12)

#define IIC1_ESDA_INP	GPD1CON &= ~(0xf<<8)
#define IIC1_ESDA_OUTP	GPD1CON = (GPD1CON & ~(0xf<<8))|(0x1<<8)

#ifdef CONFIG_SMDKC220
#define IIC3_ESCL_INP	GPA1CON &= ~(0xf<<12)
#define IIC3_ESCL_OUTP	GPA1CON = (GPA1CON & ~(0xf<<12))|(0x1<<12)

#define IIC3_ESDA_INP	GPA1CON &= ~(0xf<<8)
#define IIC3_ESDA_OUTP	GPA1CON = (GPA1CON & ~(0xf<<8))|(0x1<<8)
#endif

#define DELAY		10

// Power Key Handling
#define GPX1CON		*(volatile unsigned long *)(0x11000000+0x0C20)
#define GPX1DAT		*(volatile unsigned long *)(0x11000000+0x0C24)
#define GPX1PUD		*(volatile unsigned long *)(0x11000000+0x0C28)

// LED Handling
#define GPX2CON		*(volatile unsigned long *)(0x11000000+0x0C40)
#define GPX2DAT		*(volatile unsigned long *)(0x11000000+0x0C44)
#define GPX2PUD		*(volatile unsigned long *)(0x11000000+0x0C48)

#define GPX3CON		*(volatile unsigned long *)(0x11000000+0x0C60)
#define GPX3DAT		*(volatile unsigned long *)(0x11000000+0x0C64)
#define GPX3PUD		*(volatile unsigned long *)(0x11000000+0x0C68)

#define BQ24160_ADDR    0xD6
#define BQ27621_ADDR    0xAA

#define BQ24160_LED_ON 		1
#define BQ24160_LED_OFF 	0

/* Register 0x0 state */
/*
000- No Valid Source Detected
001- IN Ready (shows preferred source when both connected)
010- USB Ready (shows preferred source when both connected)
011- Charging from IN
100- Charging from USB
101- Charge Done
110- NA
111- Fault
*/

#define BQ24160_REG0_STATE_NO_SOURCE          0x00
#define BQ24160_REG0_STATE_IN_READY           0x10
#define BQ24160_REG0_STATE_USB_READY          0x20
#define BQ24160_REG0_STATE_CHARGING_FROM_IN   0x30
#define BQ24160_REG0_STATE_CHARGING_FROM_USB  0x40
#define BQ24160_REG0_STATE_CHARGE_DONE        0x50
#define BQ24160_REG0_STATE_NA                 0x60
#define BQ24160_REG0_STATE_FAULT              0x70

typedef enum {
	BQ24160_LED_STATE_CHARGING,
	BQ24160_LED_STATE_CHARGE_DONE,
	BQ24160_LED_STATE_CHARGE_NONE
}charge_led_state;

extern void bq24160_Process(void);

#endif /*__BQ24160_H__*/

